@@ -1,5 +1,7 @@
 """Test config file searching for tmuxp."""
 
+from __future__ import annotations
+
 import argparse
 import pathlib
 import typing as t
@@ -61,23 +63,83 @@ def test_get_configs_cwd(
     assert ".tmuxp.json" in configs_found
 
 
+class PureNameTestFixture(t.NamedTuple):
+    """Test fixture for verifying pure name path validation."""
+
+    test_id: str
+    path: str
+    expect: bool
+
+
+PURE_NAME_TEST_FIXTURES: list[PureNameTestFixture] = [
+    PureNameTestFixture(
+        test_id="current_dir",
+        path=".",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="current_dir_slash",
+        path="./",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="empty_path",
+        path="",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="tmuxp_yaml",
+        path=".tmuxp.yaml",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="parent_tmuxp_yaml",
+        path="../.tmuxp.yaml",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="parent_dir",
+        path="../",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="absolute_path",
+        path="/hello/world",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="home_tmuxp_path",
+        path="~/.tmuxp/hey",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="home_work_path",
+        path="~/work/c/tmux/",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="home_work_tmuxp_yaml",
+        path="~/work/c/tmux/.tmuxp.yaml",
+        expect=False,
+    ),
+    PureNameTestFixture(
+        test_id="pure_name",
+        path="myproject",
+        expect=True,
+    ),
+]
+
+
 @pytest.mark.parametrize(
-    ("path", "expect"),
-    [
-        (".", False),
-        ("./", False),
-        ("", False),
-        (".tmuxp.yaml", False),
-        ("../.tmuxp.yaml", False),
-        ("../", False),
-        ("/hello/world", False),
-        ("~/.tmuxp/hey", False),
-        ("~/work/c/tmux/", False),
-        ("~/work/c/tmux/.tmuxp.yaml", False),
-        ("myproject", True),
-    ],
+    list(PureNameTestFixture._fields),
+    PURE_NAME_TEST_FIXTURES,
+    ids=[test.test_id for test in PURE_NAME_TEST_FIXTURES],
 )
-def test_is_pure_name(path: str, expect: bool) -> None:
+def test_is_pure_name(
+    test_id: str,
+    path: str,
+    expect: bool,
+) -> None:
     """Test is_pure_name() is truthy when file, not directory or config alias."""
     assert is_pure_name(path) == expect
 
@@ -104,7 +166,7 @@ def test_tmuxp_configdir_xdg_config_dir(
     assert get_workspace_dir() == str(tmux_dir)
 
 
-@pytest.fixture()
+@pytest.fixture
 def homedir(tmp_path: pathlib.Path) -> pathlib.Path:
     """Fixture to ensure and return a home directory."""
     home = tmp_path / "home"
@@ -112,7 +174,7 @@ def homedir(tmp_path: pathlib.Path) -> pathlib.Path:
     return home
 
 
-@pytest.fixture()
+@pytest.fixture
 def configdir(homedir: pathlib.Path) -> pathlib.Path:
     """Fixture to ensure user directory for tmuxp and return it, via homedir fixture."""
     conf = homedir / ".tmuxp"
@@ -120,7 +182,7 @@ def configdir(homedir: pathlib.Path) -> pathlib.Path:
     return conf
 
 
-@pytest.fixture()
+@pytest.fixture
 def projectdir(homedir: pathlib.Path) -> pathlib.Path:
     """Fixture to ensure and return an example project dir."""
     proj = homedir / "work" / "project"
@@ -156,7 +218,7 @@ def test_resolve_dot(
     assert find_workspace_file("../project") == expect
     assert find_workspace_file("../project/") == expect
     assert find_workspace_file(".tmuxp.yaml") == expect
-    assert find_workspace_file("../../.tmuxp/%s.yaml" % user_config_name) == str(
+    assert find_workspace_file(f"../../.tmuxp/{user_config_name}.yaml") == str(
         user_config,
     )
     assert find_workspace_file("myconfig") == str(user_config)
@@ -178,8 +240,8 @@ def test_resolve_dot(
     assert find_workspace_file("work/project/") == expect
     assert find_workspace_file("./work/project") == expect
     assert find_workspace_file("./work/project/") == expect
-    assert find_workspace_file(".tmuxp/%s.yaml" % user_config_name) == str(user_config)
-    assert find_workspace_file("./.tmuxp/%s.yaml" % user_config_name) == str(
+    assert find_workspace_file(f".tmuxp/{user_config_name}.yaml") == str(user_config)
+    assert find_workspace_file(f"./.tmuxp/{user_config_name}.yaml") == str(
         user_config,
     )
     assert find_workspace_file("myconfig") == str(user_config)
@@ -202,8 +264,8 @@ def test_resolve_dot(
     assert find_workspace_file("../work/project") == expect
     assert find_workspace_file("../../home/work/project") == expect
     assert find_workspace_file("../work/project/") == expect
-    assert find_workspace_file("%s.yaml" % user_config_name) == str(user_config)
-    assert find_workspace_file("./%s.yaml" % user_config_name) == str(user_config)
+    assert find_workspace_file(f"{user_config_name}.yaml") == str(user_config)
+    assert find_workspace_file(f"./{user_config_name}.yaml") == str(user_config)
     assert find_workspace_file("myconfig") == str(user_config)
     assert find_workspace_file("~/.tmuxp/myconfig.yaml") == str(user_config)
 
@@ -223,10 +285,10 @@ def test_resolve_dot(
     expect = str(project_config)
     assert find_workspace_file("home/work/project") == expect
     assert find_workspace_file("./home/work/project/") == expect
-    assert find_workspace_file("home/.tmuxp/%s.yaml" % user_config_name) == str(
+    assert find_workspace_file(f"home/.tmuxp/{user_config_name}.yaml") == str(
         user_config,
     )
-    assert find_workspace_file("./home/.tmuxp/%s.yaml" % user_config_name) == str(
+    assert find_workspace_file(f"./home/.tmuxp/{user_config_name}.yaml") == str(
         user_config,
     )
     assert find_workspace_file("myconfig") == str(user_config)
@@ -267,7 +329,7 @@ def test_find_workspace_file_arg(
 
     project_config = projectdir / ".tmuxp.yaml"
 
-    def check_cmd(config_arg: str) -> "_pytest.capture.CaptureResult[str]":
+    def check_cmd(config_arg: str) -> _pytest.capture.CaptureResult[str]:
         args = parser.parse_args([config_arg])
         config_cmd(workspace_file=args.workspace_file)
         return capsys.readouterr()
@@ -280,7 +342,7 @@ def test_find_workspace_file_arg(
     assert expect in check_cmd("../project").out
     assert expect in check_cmd("../project/").out
     assert expect in check_cmd(".tmuxp.yaml").out
-    assert str(user_config) in check_cmd("../../.tmuxp/%s.yaml" % user_config_name).out
+    assert str(user_config) in check_cmd(f"../../.tmuxp/{user_config_name}.yaml").out
     assert user_config.stem in check_cmd("myconfig").out
     assert str(user_config) in check_cmd("~/.tmuxp/myconfig.yaml").out
 
